package com.diagbot.web;

import com.diagbot.annotation.SysLogger;
import com.diagbot.dto.GraphDTO;
import com.diagbot.dto.NodeDTO;
import com.diagbot.dto.RespDTO;
import com.diagbot.facade.KgFacade;
import com.diagbot.vo.KgQueryVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import java.util.List;
import java.util.Map;

/**
 * @Description: 朗通知识图谱控制层
 * @author: gaodm
 * @time: 2018/8/30 10:12
 */
@RestController
@RequestMapping("/kg")
@Api(value = "朗通知识图谱API", tags = { "朗通知识图谱API" })
@SuppressWarnings("unchecked")
public class KgController {

    @Autowired
    private KgFacade kgFacade;

    @ApiOperation(value = "查询节点", notes = "查询节点")
    @PostMapping("/getNode")
    @SysLogger("getNode")
    public RespDTO<List<NodeDTO>> getNode(@RequestBody KgQueryVO kgQueryVO) {
        return RespDTO.onSuc(kgFacade.getNode(kgQueryVO));
    }

    @ApiOperation(value = "获取图谱", notes = "获取图谱")
    @PostMapping("/getGraph")
    @SysLogger("getGraph")
    public RespDTO<List<GraphDTO>> getGraph(@RequestBody @Valid KgQueryVO kgQueryVO) {
        return RespDTO.onSuc(kgFacade.getGraph(kgQueryVO));
    }

    @ApiOperation(value = "获取分类", notes = "获取分类")
    @PostMapping("/getTree")
    @SysLogger("getTree")
    public RespDTO<List<Map>> getTree() {
        return RespDTO.onSuc(kgFacade.getTree());
    }

    @ApiOperation(value = "获取描述框架", notes = "获取描述框架")
    @PostMapping("/getSchema")
    @SysLogger("getSchema")
    public RespDTO<List<Map>> getSchema() {
        return RespDTO.onSuc(kgFacade.getSchema());
    }
}

